@@ -3,6 +3,7 @@ from __future__ import absolute_import
 
 
 smev245 = "http://smev.gosuslugi.ru/rev111111"
+smev255 = "http://smev.gosuslugi.ru/rev120315"
 smev256 = "http://smev.gosuslugi.ru/rev120315"
 soapenv = "http://schemas.xmlsoap.org/soap/envelope/"
 wsdl = "http://schemas.xmlsoap.org/wsdl/"
@@ -27,6 +28,20 @@ md5 = "http://www.w3.org/2000/09/xmldsig-more#md5"
 rsa_md5 = "http://www.w3.org/2000/09/xmldsig-more#rsa-md5"
 gost94 = "http://www.w3.org/2001/04/xmldsig-more#gostr3411"
 gost2001 = "http://www.w3.org/2001/04/xmldsig-more#gostr34102001-gostr3411"
+gost2012_256 = (
+    "urn:ietf:params:xml:ns:cpxmlsec:"
+    "algorithms:gostr34102012-gostr34112012-256"
+)
+md_gost2012_256 = (
+    "urn:ietf:params:xml:ns:cpxmlsec:algorithms:gostr34112012-256"
+)
+gost2012_512 = (
+     "urn:ietf:params:xml:ns:cpxmlsec:"
+     "algorithms:gostr34102012-gostr34112012-512"
+)
+md_gost2012_512 = (
+    "urn:ietf:params:xml:ns:cpxmlsec:algorithms:gostr34112012-512"
+)
 
 exc_c14n = "http://www.w3.org/2001/10/xml-exc-c14n#"
 exc_c14n_wc = "http://www.w3.org/2001/10/xml-exc-c14n#WithComments"
@@ -51,6 +66,9 @@ nsmap = {
     'ds': ds,
     'wsdl': wsdl,
 }
+nsmap255 = nsmap.copy()
+nsmap255.update({'smev': smev255})
+
 nsmap256 = nsmap.copy()
 nsmap256.update({'smev': smev256})
 
